#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Sun Mar 25 23:31:05 2018

@author: mischaknabenhans

Evaluation of the logistic equation and representation of its solutions in
a Feigenbaum diagram.
"""

#%% Import modules
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm

#%% Logistic equation

def LogEq(x,r,MAXITER):
    """
    Computation of the logistic equation for a initial value x and a rate r.
    NOTICE: x and r are also allowed to be of type np.ndarray.
    """
    n=0
    while n<=MAXITER:
        x = x*r*(1-x)
        n += 1
        
    return x

#%% Main

rList = np.linspace(0.01,4,800)
x_i_List = np.linspace(0.01,1,200)
MaxIter = 500

[x,r] = np.meshgrid(x_i_List,rList)
Feigenbaum=LogEq(x,r,MaxIter)

#%% Plot
Fig, ax = plt.subplots()
for i in xrange(len(rList)):
    ax.scatter(rList[i]*np.ones_like(Feigenbaum[i]),Feigenbaum[i], 
               s=0.01, c='k')

ax.set_xlim([2.5,4])
ax.set_ylim([0,1])
ax.set_xlabel("r")
ax.set_ylabel(r"x_"+str(MaxIter))
ax.set_title("Feigenbaum diagram")
plt.show()
    
    