#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Sun Mar 25 12:51:11 2018

@author: mischaknabenhans

Plotting the Mandelbrot set for an input parameter C.
"""
#%% Import modules
import numpy as np
#import numpy.ma as ma
import matplotlib.pyplot as plt
import matplotlib.cm as cm

#%% Mandelbrot class
class Mandelbrot(object):
    """
    This is the Mandelbrot class characterized by a grid (X,Y)
    corrsponding to the real (X) and imaginary part of the tested 
    parameters C.
    """
    
    def __init__(self,grid):
        """
        Initializer of class Mandelbrot
        """
        self.grid = grid
        self.C = grid[0] + 1j*grid[1]

    def full_recursion(self,MAXITER):
        """
        Computes the mandelbrot set
        """
        z = np.zeros_like(self.C)
        MandelbrotSet = np.zeros_like(self.grid[0])
        n = 0
        
        maxMat = 2*np.ones_like(self.grid[0])
        maxMat[maxMat<abs(self.C)]=abs(self.C[maxMat<abs(self.C)])
        
        mask = np.ones_like(self.C, dtype=bool)
        while n <= MAXITER:
            #print(n)
            #z = z*z + self.C
            z[mask] = z[mask]*z[mask] + self.C[mask]
            mask = (abs(z)<=maxMat)
            MandelbrotSet[mask]=n 
            n += 1
           
        return MandelbrotSet

#%% Main function 
MaxIter = 100

#[re_min,re_max] = [-2,1]
#[im_min,im_max] = [-1,1]
[re_min,re_max] = [-1.4,-1.3]
[im_min,im_max] = [-0.05,0.05]


X = np.linspace(re_min,re_max,601)
Y = np.linspace(im_min,im_max,401)

grid = np.meshgrid(X,Y)

M = Mandelbrot(grid)
Data = M.full_recursion(MaxIter)


#%% Plot Mandelbrot set
my_cmap = cm.get_cmap('rainbow')
fig, ax = plt.subplots(figsize=(6, 9))
ax.contourf(grid[0],grid[1],Data, cmap=my_cmap)
ax.set_xlabel("Re(C)")
ax.set_ylabel("Im(C)")
ax.set_title("Mandelbrot set")
plt.show()